@@ -209,8 +209,9 @@ public Q_SLOTS:
 
     /**
      * Opens a new tab in the background showing the URL \a url.
+     * @return A pointer to the opened DolphinTabPage.
      */
-    void openNewTab(const QUrl &url);
+    DolphinTabPage *openNewTab(const QUrl &url);
 
     /**
      * Opens a new tab  showing the URL \a url and activate it.
@@ -295,6 +296,7 @@ private Q_SLOTS:
     void updateNewMenu();
 
     void createDirectory();
+    void createFile();
 
     /** Shows the error message in the status bar of the active view. */
     void showErrorMessage(const QString &message);
